#!python

from numpy import cos, sin, pi, absolute, arange, log10
from scipy.signal import kaiserord, lfilter, firwin, freqz
from pylab import figure, clf, plot, xlabel, ylabel, xlim, ylim, title, grid, axes, show

# Частота дискретизации, Гц
sample_rate = 20000.0

# Частота Найквиста
nyq_rate = sample_rate / 2.0

# Полоса пропускания ФНЧ, Гц
cutoff_hz = 2700.0

# Ширина интервала между частотой среза (полоса пропускания) и частотой, с которой начинается полоса задерживания.
# Безразмерная величина (ширина интервала по отношению к частоте Найквиста)
width = 1300.0/nyq_rate

# Минимальное допустимое ослабление в полосе задерживания, дБ
ripple_db = 70.0

# Расчет порядка фильтра с КИХ (переменная N) и параметра beta для окна Кайзера.
N, beta = kaiserord(ripple_db, width)

# Расчет коэффициентов ФНЧ с КИХ с использованием окна Кайзера
taps = firwin(N, cutoff_hz/nyq_rate, window=('kaiser', beta))

# Печать коэффициентов фильтра 
#print (taps, '\n')

print('Коэффициенты фильтра')
print('N=', N)

j = 0
while j < N:
    print("{:4d}".format(j), "{:22.12E}".format(taps[j]))
    j +=1

#------------------------------------------------
# График коэффициентов фильтра
#------------------------------------------------

figure(1)
plot(taps, 'bo-', linewidth=2)
title('Коэффициенты фильтра (%d точек)' % N)
grid(True)

#------------------------------------------------
# График АЧХ фильтра
#------------------------------------------------

figure(2)
clf()
w, h = freqz(taps, worN=8000)
plot((w/pi)*nyq_rate, 20*log10(absolute(h)), linewidth=2)
xlabel('Частота ,Гц')
ylabel('Уровень, дБ')
title('АЧХ фильтра')
ylim(-100.0, 20.0)
grid(True)

show()